@@ -13,17 +13,20 @@ import networkx as nx
 from dateutil import parser
 import matplotlib.pyplot as plt
 from Bio.UniProt import GOA
+import configparser
 
-DATADIR = "data/"
+
+
+# ONTO_DIR = "data/"
 # Some filenames
-FILE_ALTERNATE_ID_TO_ID_MAPPING = DATADIR + "alt_to_id.graph"
-FILE_CAFA_ID_TO_UNIPROT_ID_MAP = DATADIR + "CAFAIDTOUniprotIDMap.txt"
-FILE_MFO_ONTOLOGY_GRAPH = DATADIR + "mf.graph"
-FILE_BPO_ONTOLOGY_GRAPH = DATADIR + "bp.graph"
-FILE_CCO_ONTOLOGY_GRAPH = DATADIR + "cc.graph"
-FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = DATADIR + "mf_ancestors.map"
-FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = DATADIR + "bp_ancestors.map"
-FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = DATADIR + "cc_ancestors.map"
+# FILE_ALTERNATE_ID_TO_ID_MAPPING = ONTO_DIR + "alt_to_id.graph"
+# FILE_CAFA_ID_TO_UNIPROT_ID_MAP = ONTO_DIR + "CAFAIDTOUniprotIDMap.txt"
+# FILE_MFO_ONTOLOGY_GRAPH = ONTO_DIR + "mf.graph"
+# FILE_BPO_ONTOLOGY_GRAPH = ONTO_DIR + "bp.graph"
+# FILE_CCO_ONTOLOGY_GRAPH = ONTO_DIR + "cc.graph"
+# FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = ONTO_DIR + "mf_ancestors.map"
+# FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = ONTO_DIR + "bp_ancestors.map"
+# FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = ONTO_DIR + "cc_ancestors.map"
 
 verbose = 0
 options = ""
@@ -94,6 +97,9 @@ def column(matrix, i):
 
 
 def print_details_about_data(data):
+    """
+    Function to print summary of input data on the screen
+    """
     print("Total number of annotations in the provided Database ", len(data))
     prots = []
     ref = []
@@ -106,6 +112,9 @@ def print_details_about_data(data):
 
 
 def count_proteins(data):
+    """
+    Counts total number of unique proteins in the input data and outputs a single integer
+    """
     allprots = []
     for annotation in data:
         allprots.append(data[annotation]['DB'] + "_" + data[annotation]['DB_Object_ID'])
@@ -113,6 +122,10 @@ def count_proteins(data):
 
 
 def freq_go_term(data):
+    """
+    This function creates a dictionary structure where keys are GO terms and values are counts of each GO term
+    occurring in the input data
+    """
     go_to_freq = {}
     for annotation in data:
         if data[annotation]['GO_ID'] in go_to_freq:
@@ -149,6 +162,7 @@ def choose_proteins_based_on_publications(data, cutoff_prot, cutoff_attn):
     simple_g = nx.Graph(g)  # Converting the multi graph to a simple graph without parallel edges
 
     no_of_prot_annotations_by_each_ref = []
+
     for ref in list(set(column(mapping, 1))):
         no_of_prot_annotations_by_each_ref.append(simple_g.degree(ref))
 
@@ -175,33 +189,33 @@ def choose_proteins_based_on_publications(data, cutoff_prot, cutoff_attn):
     return new_data
 
 
-def convert_to_dictionary(filename):
-    """
-    This function reads from the input gaf file and converts it to a dictionary. This function is deprecated and will
-    be removed in further releases. Instead of using this function the program now makes use of the gaf iterator
-    function from biopython.
-    """
-    alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
-    fhr = open(filename, "r")
-    data = {}
-    counter = 1
-    for line in fhr:
-        if "!" not in line:
-            line = line.split("\t")
-            id = "anntn" + str(counter)
-            per_annotation = {}
-            for f_no, field in enumerate(GAF21FIELDS):
-                if field == "GO_ID":
-                    if line[f_no].strip() in alt_id_to_id_map:
-                        # print(line[f_no].strip())
-                        line[f_no] = alt_id_to_id_map[line[f_no].strip()]
-                per_annotation[field] = line[f_no]
-            data[id] = per_annotation
-            counter += 1
-            """if(len(data)==10):
-                break"""
-    fhr.close()
-    return data
+# def convert_to_dictionary(filename):
+#     """
+#     This function reads from the input gaf file and converts it to a dictionary. This function is deprecated and will
+#     be removed in further releases. Instead of using this function the program now makes use of the gaf iterator
+#     function from biopython.
+#     """
+#     alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
+#     fhr = open(filename, "r")
+#     data = {}
+#     counter = 1
+#     for line in fhr:
+#         if "!" not in line:
+#             line = line.split("\t")
+#             id = "anntn" + str(counter)
+#             per_annotation = {}
+#             for f_no, field in enumerate(GAF21FIELDS):
+#                 if field == "GO_ID":
+#                     if line[f_no].strip() in alt_id_to_id_map:
+#                         # print(line[f_no].strip())
+#                         line[f_no] = alt_id_to_id_map[line[f_no].strip()]
+#                 per_annotation[field] = line[f_no]
+#             data[id] = per_annotation
+#             counter += 1
+#             """if(len(data)==10):
+#                 break"""
+#     fhr.close()
+#     return data
 
 
 def convert_from_gaf_to_required_format(gaf):
@@ -209,6 +223,7 @@ def convert_from_gaf_to_required_format(gaf):
     This function takes the data input which is created by gaf iterator and then makes few changes 
     in the annotations which is relevant to this program.
     """
+    # print("in format converter", os.getcwd())
     alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
     counter = 1
     data = {}
@@ -230,24 +245,31 @@ def write_to_file(data, filename, input_filename):
     This function will write the content of the data structure 'data' to the output file. 
     It requires the input file to read the header. Inclusion of the header is mandatory.
     """
-    vprint("Writing to file ", filename)
-    # print(filename)
-    filepath = "/".join(filename.split("/")[:-1])
+    # print("Writing to file ", filename)
+    # print("filename", filename, "\n", "inputfilename", input_filename)
+    if os.path.sep in filename:
+        filepath = os.path.sep.join(filename.split(os.path.sep)[:-1])
+    else:
+        filepath = os.path.join(os.path.sep, filename)
+    # filepath = os.path.join(filename)
+    # filepath = os.path.join(os.path.sep, os.getcwd(), filename)
+    # print("filepath", filepath, "\n", "splitfilepath", filename.split(os.path.sep)[:-1])
     try:
-        if os.path.isdir(filepath) == False:
+        if not os.path.isdir(filepath):
             os.makedirs(filepath)
     except OSError:
         print(
             "You do not have sufficient Permissions to create the folder. Please alter the permissions or provide a "
             "different path.")
         sys.exit()
-    fhr = open(input_filename, "r")
+    fhr = open(os.path.abspath(input_filename), "r")
     header = ""
     for line in fhr:
         if line[0] == '!':
             header += line
     fhr.close()
-    fhw = open(filename + ".gaf", "w")
+    # print("this is filename", filename)
+    fhw = open(os.path.abspath(filename) + ".gaf", "w")
     fhw.write(header)
     for key in data:
         per_annotation = data[key]
@@ -291,6 +313,7 @@ def choose_proteins_based_on_evidence_codes(data, evidence_list, evidence_invers
     """
     This function will select only those annotations which have been annotated by the provided Evidence Codes
     """
+    # print("in ec function")
     # Checking whether the provided Evidence codes are correct or not
     if evidence_list is not None:
         if check_evidence_code_for_correctness(evidence_list) == False:
@@ -459,7 +482,9 @@ def create_protein_to_go_mapping(data):
     """
     prot_to_go = {}
     all_GO = []
-    alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
+    # alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
+    f = open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb")
+    alt_id_to_id_map = cp.load(f)
     for attnid in data:
         annotation = data[attnid]
         prot_id = annotation['DB'] + '_' + annotation['DB_Object_ID']
@@ -474,7 +499,9 @@ def create_protein_to_go_mapping(data):
         else:
             if [GO_term, annotation['Aspect']] not in prot_to_go[prot_id]:
                 prot_to_go[prot_id].append([GO_term, annotation['Aspect']])
+        # print(prot_id, prot_to_go[prot_id])
         # vprint(prot_to_go[prot_id])
+    f.close()
     return prot_to_go, list(set(all_GO))
 
 
@@ -505,10 +532,14 @@ def propagate_ontologies(Prot_to_GO_Map):
                 ancestors.extend(cc_ancestors[GO_term])
         ancestors = list(set(ancestors))
         Prot_to_GO_Map_new[eachprotein] = ancestors
+        # print(Prot_to_GO_Map_new)
     return Prot_to_GO_Map_new
 
 
 def find_frequency(annotations, Prot_to_GO_Map):
+    """
+        This function counts number of annotations per protein
+    """
     count = 0
     if annotations == None:
         return 0
@@ -519,6 +550,10 @@ def find_frequency(annotations, Prot_to_GO_Map):
 
 
 def assign_probabilities_to_ontology_tree(g, Prot_to_GO_Map, all_GO_Terms, ontology_to_ia_map, aspect):
+    """
+        Each node is a GO term and this function calculates per term information content by parsing the protein to GO
+        mapping graph
+    """
     for node_num, node in enumerate(g.nodes()):
         if node not in all_GO_Terms:
             ontology_to_ia_map[node] = [0, 0]
@@ -533,8 +568,8 @@ def assign_probabilities_to_ontology_tree(g, Prot_to_GO_Map, all_GO_Terms, ontol
         denom = find_frequency(predecessor, Prot_to_GO_Map)
         num = find_frequency(predecessor_with_node, Prot_to_GO_Map)
         # vprint(node,g.successors(node))
-        """vprint(predecessor_with_node,num)
-        vprint(predecessor,denom)"""
+        # vprint(predecessor_with_node,num)
+        # vprint(predecessor,denom)
         if denom == 0:
             prob = 0
         else:
@@ -543,6 +578,9 @@ def assign_probabilities_to_ontology_tree(g, Prot_to_GO_Map, all_GO_Terms, ontol
 
 
 def assign_probabilities_to_ontology_graphs(Prot_to_GO_Map, all_GO_Terms, aspects):
+    """
+        This function calculates per GO term information content for individual ontologies - MFO, BPO and CCO
+    """
     mf_g = cp.load(open(FILE_MFO_ONTOLOGY_GRAPH, "rb"))
     bp_g = cp.load(open(FILE_BPO_ONTOLOGY_GRAPH, "rb"))
     cc_g = cp.load(open(FILE_CCO_ONTOLOGY_GRAPH, "rb"))
@@ -550,8 +588,8 @@ def assign_probabilities_to_ontology_graphs(Prot_to_GO_Map, all_GO_Terms, aspect
     assign_probabilities_to_ontology_tree(mf_g, Prot_to_GO_Map, all_GO_Terms, ontology_to_ia_map, 'MFO')
     assign_probabilities_to_ontology_tree(bp_g, Prot_to_GO_Map, all_GO_Terms, ontology_to_ia_map, 'BPO')
     assign_probabilities_to_ontology_tree(cc_g, Prot_to_GO_Map, all_GO_Terms, ontology_to_ia_map, 'CCO')
-    """for GO in ontology_to_ia_map:
-        vprint(ontology_to_ia_map[GO])"""
+    # for GO in ontology_to_ia_map:
+    #     vprint(ontology_to_ia_map[GO])
     # fileTemp1 = open("IC.txt", "w")
     # for GO in ontology_to_ia_map:
     # fileTemp1.write(GO + "\t")
@@ -569,35 +607,43 @@ def assign_probabilities_to_ontology_graphs(Prot_to_GO_Map, all_GO_Terms, aspect
     return ontology_to_ia_map
 
 
-def calculate_information_accretion_for_each_protein(Prot_to_GO_Map, ontology_to_ia_map):
-    vprint("Starting calculation of ia")
-    infoAccr = {}
-    alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
-    for prot in Prot_to_GO_Map:
-        annotations = Prot_to_GO_Map[prot]
-        ia = 0
-        for annotation in annotations:
-            if len(annotation) == 2:
-                GO_term = annotation[0]
-            else:
-                GO_term = annotation
-            if GO_term not in ontology_to_ia_map:
-                GO_term = alt_id_to_id_map[GO_term]
-            # vprint(prot,annotation[0])
-            ia += ontology_to_ia_map[GO_term][1]
-        infoAccr[prot] = ia
-    return infoAccr
+# def calculate_information_accretion_for_each_protein(Prot_to_GO_Map, ontology_to_ia_map):
+#     """
+#         From the protein to GO term mapping data structure, this function calculates information accretion per protein by
+#         summing information content of each GO term that the protein is annotated with
+#     """
+#     vprint("Starting calculation of ia")
+#     infoAccr = {}
+#     alt_id_to_id_map = cp.load(open(FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb"))
+#     for prot in Prot_to_GO_Map:
+#         annotations = Prot_to_GO_Map[prot]
+#         ia = 0
+#         for annotation in annotations:
+#             if len(annotation) == 2:
+#                 GO_term = annotation[0]
+#             else:
+#                 GO_term = annotation
+#             if GO_term not in ontology_to_ia_map:
+#                 GO_term = alt_id_to_id_map[GO_term]
+#             # vprint(prot,annotation[0])
+#             ia += ontology_to_ia_map[GO_term][1]
+#         infoAccr[prot] = ia
+#     return infoAccr
 
 
 def calculate_phillip_lord_information_content(data, crisp, percentile_val):
+    """
+    This function will calculate per GO term Information content values, and remove the annotations below a threshold
+    or percentile, when the respective values are provided.
+    """
     go_terms = []
-    """Prot_to_GO_Map, all_GO_Terms_in_corpus = create_protein_to_go_mapping( data )
-    Prot_to_GO_Map_propagated = propagate_ontologies( Prot_to_GO_Map )"""
+    # Prot_to_GO_Map, all_GO_Terms_in_corpus = create_protein_to_go_mapping( data )
+    # Prot_to_GO_Map_propagated = propagate_ontologies( Prot_to_GO_Map )
     # alt_id_to_id_map = cp.load( open( FILE_ALTERNATE_ID_TO_ID_MAPPING, "rb" ) )
-    """for eachprot in Prot_to_GO_Map:
-        go_terms.extend([annotation[0] for annotation in Prot_to_GO_Map[eachprot]])"""
-    """for eachprot in Prot_to_GO_Map_propagated:
-        go_terms.extend(Prot_to_GO_Map_propagated[eachprot])"""
+    # for eachprot in Prot_to_GO_Map:
+    #     go_terms.extend([annotation[0] for annotation in Prot_to_GO_Map[eachprot]])
+    # for eachprot in Prot_to_GO_Map_propagated:
+    #     go_terms.extend(Prot_to_GO_Map_propagated[eachprot])
 
     for attnid in data:
         go_terms.append(data[attnid]["GO_ID"])
@@ -625,6 +671,7 @@ def calculate_phillip_lord_information_content(data, crisp, percentile_val):
     for attnid in data:
         annotation = data[attnid]
         if GO_term_to_PL_info[annotation["GO_ID"]] >= threshold:
+            # print(attnid)
             new_data[attnid] = data[attnid]
     return new_data
     # vprint(collections.Counter(go_terms))
@@ -633,11 +680,17 @@ def calculate_phillip_lord_information_content(data, crisp, percentile_val):
 def calculate_wyatt_clark_information_content(data, recal, crisp, percentile_val, aspects, outputfiles, input_num):
     """
     This function will display some essential statistics when the value of threshold 
-    is crisp and a percentile is not provided.
+    is crisp and a percentile is not provided. Additionally, based on threshold or percentile cut-offs, will also
+    filter annotations
     """
+    # print(recal, crisp, percentile_val, aspects, outputfiles, input_num)
     # vprint(outputfiles[0].split("_"))
+    # print("wc output files", outputfiles)
+    # print(outputfiles[input_num].split("_")[:-2])
+    # ontology_to_ia_map_filename = "ontology_to_ia_map_" + "_".join(
+    #     outputfiles[input_num].split("/")[-1].split("_")[:-2]) + ".txt"
     ontology_to_ia_map_filename = "ontology_to_ia_map_" + "_".join(
-        outputfiles[input_num].split("/")[-1].split("_")[:-2]) + ".txt"
+            outputfiles[input_num].split(os.path.sep)[-1].split("_")[:-2]) + ".txt"
     # vprint(ontology_to_ia_map_filename)
     # exit()
     Prot_to_GO_Map, all_GO_Terms_in_corpus = create_protein_to_go_mapping(data)
@@ -648,13 +701,18 @@ def calculate_wyatt_clark_information_content(data, recal, crisp, percentile_val
             "depending on the size of input")
         ontology_to_ia_map = assign_probabilities_to_ontology_graphs(Prot_to_GO_Map_propagated, all_GO_Terms_in_corpus,
                                                                      aspects)
-        if os.path.isdir("data/temp/") == False:
-            os.makedirs("data/temp/")
-        cp.dump(ontology_to_ia_map, open("data/temp/" + ontology_to_ia_map_filename, "wb"))
+        tmpdir = os.path.join(ONTO_DIR, "temp")
+        if os.path.isdir(tmpdir) == False:
+            os.makedirs(tmpdir)
+        # print("ontology to ia filename", ontology_to_ia_map_filename)
+        cp.dump(ontology_to_ia_map, open(os.path.join(tmpdir, ontology_to_ia_map_filename), "wb"))
     else:
         vprint("Skipping recalculation of Information Accretion for Wyatt Clark")
     try:
-        ontology_to_ia_map = cp.load(open("data/temp/" + ontology_to_ia_map_filename, "rb"))
+        tmpdir = os.path.join(ONTO_DIR, "temp")
+        # print(ontology_to_ia_map_filename)
+        # print(ONTO_DIR)
+        ontology_to_ia_map = cp.load(open(os.path.join(tmpdir, ontology_to_ia_map_filename), "rb"))
     except IOError as e:
         print("File for GO_Term to ia NOT FOUND. Please rerun the program with the argument -recal 1")
         exit()
@@ -689,6 +747,9 @@ def calculate_wyatt_clark_information_content(data, recal, crisp, percentile_val
 
 
 def vprint(*s):
+    """
+    When verbose option is selected, this function will print output of commands on screen
+    """
     global verbose
     # print(s,verbose)
     if verbose == 1:
@@ -698,6 +759,10 @@ def vprint(*s):
 
 
 def change_name_of_output_files(options):
+    """
+    This function customizes names of output files based on the user set of arguments
+    """
+    # print(options)
     longAspect = {'P': 'BPO', 'C': 'CCO', 'F': 'MFO'}
     if options.prefix is not None:
         prefix = options.prefix
@@ -705,9 +770,12 @@ def change_name_of_output_files(options):
         prefix = ""
     if options.output == None:
         options.output = []
-        path = "./" + prefix
+        # path = "./" + prefix
+        # print(os.getcwd())
+        path = os.path.join(prefix)
     else:
-        path = options.output + "/" + prefix
+        # path = options.output + "/" + prefix
+        path = os.path.join(options.output, prefix)
         options.output = []
 
     # vprint("Output Options ",options.output)
@@ -716,9 +784,14 @@ def change_name_of_output_files(options):
         # vprint(inputfile)
 
         # vprint("Output file: "+options.output)
-        file = inputfile.split("/")[-1]
+        # file = inputfile.split("/")[-1]
+        file = inputfile.split(os.path.sep)[-1]
+        # print("input file", inputfile)
+        # print("file", file)
         species = file.split(".gaf")[0].split("_")[1]
+        # print("species", species)
         # vprint("Species: " + species)
+        # final_outputfilename = path + species
         final_outputfilename = path + species
         aspect = ""
         if options.aspect:
@@ -738,26 +811,34 @@ def change_name_of_output_files(options):
         elif options.info_threshold_Wyatt_Clark_percentile:
             final_outputfilename += '_WCP_' + options.info_threshold_Wyatt_Clark_percentile
         options.output.append(final_outputfilename)
-        print("Output file: "+final_outputfilename)
+        print("Output file: " + os.path.abspath(final_outputfilename))
         # vprint(options.output[num])
         # vprint()
         # exit()
     # vprint(options.output)
+    print(options.output)
     return options.output
 
 
 def combine_output_files(outputfiles, options):
-    # print(outputfiles)
-    path = "/".join(outputfiles[0].split("/")[:-1])
-    file = outputfiles[0].split("/")[-1]
-    """if ("./" in outputfiles[0]):
-        finaloutputfilename="all_"+"_".join(file.split("_")[1:])
-    else:"""
-    finaloutputfilename = "all_" + "_".join(outputfiles[0].split("/")[-1].split("_")[1:])
+    """
+    When a single output is requested, this function will combine individual outputs for multiple input files into
+    one consolidated output file
+    """
+    # path = "/".join(outputfiles[0].split("/")[:-1])
+    path = os.path.sep.join(outputfiles[0].split(os.path.sep)[:-1])
+    # print("combine output", path)
+    # file = outputfiles[0].split("/")[-1]
+    # if ("./" in outputfiles[0]):
+    #     finaloutputfilename="all_"+"_".join(file.split("_")[1:])
+    # else:
+    # finaloutputfilename = "all_" + "_".join(outputfiles[0].split("/")[-1].split("_")[1:])
+    finaloutputfilename = "all_" + "_".join(outputfiles[0].split("_")[1:])
     if options.prefix != None:
         finaloutputfilename = options.prefix + finaloutputfilename
-    finaloutputfilename = path + "/" + finaloutputfilename
-    print("Final combined output file for all species: "+finaloutputfilename)
+    finaloutputfilename = os.path.join(path, finaloutputfilename)
+    # finaloutputfilename = path + "/" + finaloutputfilename
+    print("Final combined output file for all species: " + os.path.abspath(finaloutputfilename))
     # Combine the gaf files
     header = ""
     for line in open(outputfiles[0] + ".gaf", "r"):
@@ -773,7 +854,8 @@ def combine_output_files(outputfiles, options):
 
 def delete_temporary_files(options):
     """
-    This function deletes all the files for each organism
+    This function deletes temporary files. Additionally when a single combined output is requested, it deletes
+    outputs for individual species
     """
     # print("Inside delete temporary files")
     for filename in options.output:
@@ -781,36 +863,45 @@ def delete_temporary_files(options):
 
 
 def create_report_file(filepath, outputfilename):
+    """
+    Generates a summary statistics report of input gaf
+    """
     # print("Outputfilename ",outputfilename)
     # print("Filepath ",filepath)
     repfilepath = ""
-    if filepath[-1] == '/':
+    # print("in create report")
+    if filepath[-1] == os.path.sep:
         if os.path.isdir(filepath) == False:
             os.makedirs(filepath)
-        filepath += "report_" + "_".join(outputfilename.split("/")[-1].split("_")[1:]) + ".xlsx"
+        filepath += "report_" + "_".join(outputfilename.split(os.path.sep)[-1].split("_")[1:]) + ".tsv"
     elif filepath == ".":
-        filepath = "report_" + "_".join(outputfilename.split("/")[-1].split("_")[1:]) + ".xlsx"
+        filepath = "report_" + "_".join(outputfilename.split(os.path.sep)[-1].split("_")[1:]) + ".tsv"
     else:
-        if "/" in filepath and os.path.isdir('/'.join(filepath.split("/")[:-1])) == False:
-            os.makedirs('/'.join(filepath.split("/")[:-1]))
-        if "." in filepath.split("/")[-1]:
-            filepath = ".".join(filepath.split(".")[:-1]) + ".xlsx"
+        if os.path.sep in filepath and os.path.isdir(os.path.sep.join(filepath.split(os.path.sep)[:-1])) == False:
+            os.makedirs(os.path.sep.join(filepath.split(os.path.sep)[:-1]))
+        if "." in filepath.split(os.path.sep)[-1]:
+            filepath = ".".join(filepath.split(".")[:-1]) + ".tsv"
         else:
-            filepath += ".xlsx"
-    # print("Report Filepath ",filepath)
+            filepath += ".tsv"
+    print("Report saved in cwd ")
     return filepath
 
 
 def write_report(filename, report):
+    """
+    Writes previously generated report to a file
+    """
     # fhw=open(filename,"w")
+    # print("in report")
     all_filenames = []
-    if "/" not in filename:
+    # print(filename)
+    if os.path.sep not in filename:
         for species in report:
-            all_filenames.append(species + "_" + filename[:-4] + "tsv")
+            all_filenames.append(species + "_" + filename[:-4] + ".tsv")
     else:
         for species in report:
             all_filenames.append(
-                "/".join(filename.split("/")[:-1]) + "/" + species + "_" + filename.split("/")[1][:-4] + "tsv")
+                os.path.sep.join(filename.split(os.path.sep)[:-1]) + os.path.sep + species + "_" + filename.split(os.path.sep)[1][:-4] + ".tsv")
     # print(all_filenames)
 
     # print(report)
@@ -826,66 +917,66 @@ def write_report(filename, report):
         # print(chr(column),chr(column+1))
 
 
-def generate_histogram(options, data, species, prev, lat, msg):
-    filepath = options.histogram
-    outputfilename = options.output[0]
-
-    if filepath[-1] == '/':
-        if os.path.isdir(filepath) == False:
-            os.makedirs(filepath)
-        filepath += species.split(".gaf")[0].split("_")[-1] + "_" + "histogram_" + "_".join(
-            outputfilename.split("/")[-1].split("_")[1:]) + ".png"
-    elif filepath == ".":
-        # print("I am here")
-        filepath = species.split(".gaf")[0].split("_")[-1] + "_" + "histogram_" + "_".join(
-            outputfilename.split("/")[-1].split("_")[1:]) + ".png"
-        # print(filepath)
-    else:
-        if "/" in filepath and os.path.isdir('/'.join(filepath.split("/")[:-1])) == False:
-            os.makedirs('/'.join(filepath.split("/")[:-1]))
-        temp = species.split(".gaf")[0].split("_")[-1] + "_"
-        if "." not in filepath and "/" not in filepath:
-            filepath = species.split(".gaf")[0].split("_")[-1] + "_" + "histogram_" + "_".join(
-                outputfilename.split("/")[-1].split("_")[1:]) + ".png"
-        elif "." in filepath.split("/")[-1]:
-            filepath = "/".join((".".join(filepath.split(".")[:-1]) + ".png").split("/")[:-1]) + "/" + temp + \
-                       (".".join(filepath.split(".")[:-1]) + ".png").split("/")[-1]
-        else:
-            filepath = "/".join(filepath.split("/")[:-1]) + "/" + temp + filepath.split("/")[-1] + ".png"
-    # print("IMG filepath",filepath)
-    prev_val = [prev[key] for key in prev]
-    # print(sum(prev_val),np.mean(prev_val))
-    new_prev_val = [-math.log(val / sum(prev_val), 2) for val in prev_val]
-    # print(sum(prev_val))
-    # prev_val=new_prev_val
-    lat_val = [lat[key] for key in lat]
-    # print(sum(lat_val),np.mean(lat_val))
-    new_lat_val = [-math.log(val / sum(lat_val), 2) for val in lat_val]
-    binsize = 100
-    plt.hist(new_prev_val, bins=binsize, color='r', label="Before Debiasing", log=True)
-    plt.hist(new_lat_val, bins=binsize, color='b', label="After Debiasing", log=True)
-    # plt.xlim((0,max(max(new_prev_val)+0.1,max(new_lat_val)+0.1)))
-    plt.xlabel("Information Content")
-    plt.ylabel("Frequency")
-    plt.title("Histogram for " + species.split(".gaf")[0].split("_")[-1] + "\n" + msg)
-
-    if options.histogram == "1":
-        plt.legend(bbox_to_anchor=(0.4, 1))
-        plt.show()
-    else:
-        # plt.figure(figsize=(70,70))
-        plt.legend(bbox_to_anchor=(0.45, 1))
-        plt.savefig(filepath, dpi=900)
-        fhw = open(filepath[:-3] + ".txt", "w")
-        fhw.write(str(new_prev_val) + "\n" + str(new_lat_val))
-    plt.close()
+# def generate_histogram(options, data, species, prev, lat, msg):
+#     filepath = options.histogram
+#     outputfilename = options.output[0]
+# 
+#     if filepath[-1] == '/':
+#         if os.path.isdir(filepath) == False:
+#             os.makedirs(filepath)
+#         filepath += species.split(".gaf")[0].split("_")[-1] + "_" + "histogram_" + "_".join(
+#             outputfilename.split("/")[-1].split("_")[1:]) + ".png"
+#     elif filepath == ".":
+#         # print("I am here")
+#         filepath = species.split(".gaf")[0].split("_")[-1] + "_" + "histogram_" + "_".join(
+#             outputfilename.split("/")[-1].split("_")[1:]) + ".png"
+#         # print(filepath)
+#     else:
+#         if "/" in filepath and os.path.isdir('/'.join(filepath.split("/")[:-1])) == False:
+#             os.makedirs('/'.join(filepath.split("/")[:-1]))
+#         temp = species.split(".gaf")[0].split("_")[-1] + "_"
+#         if "." not in filepath and "/" not in filepath:
+#             filepath = species.split(".gaf")[0].split("_")[-1] + "_" + "histogram_" + "_".join(
+#                 outputfilename.split("/")[-1].split("_")[1:]) + ".png"
+#         elif "." in filepath.split("/")[-1]:
+#             filepath = "/".join((".".join(filepath.split(".")[:-1]) + ".png").split("/")[:-1]) + "/" + temp + \
+#                        (".".join(filepath.split(".")[:-1]) + ".png").split("/")[-1]
+#         else:
+#             filepath = "/".join(filepath.split("/")[:-1]) + "/" + temp + filepath.split("/")[-1] + ".png"
+#     # print("IMG filepath",filepath)
+#     prev_val = [prev[key] for key in prev]
+#     # print(sum(prev_val),np.mean(prev_val))
+#     new_prev_val = [-math.log(val / sum(prev_val), 2) for val in prev_val]
+#     # print(sum(prev_val))
+#     # prev_val=new_prev_val
+#     lat_val = [lat[key] for key in lat]
+#     # print(sum(lat_val),np.mean(lat_val))
+#     new_lat_val = [-math.log(val / sum(lat_val), 2) for val in lat_val]
+#     binsize = 100
+#     plt.hist(new_prev_val, bins=binsize, color='r', label="Before Debiasing", log=True)
+#     plt.hist(new_lat_val, bins=binsize, color='b', label="After Debiasing", log=True)
+#     # plt.xlim((0,max(max(new_prev_val)+0.1,max(new_lat_val)+0.1)))
+#     plt.xlabel("Information Content")
+#     plt.ylabel("Frequency")
+#     plt.title("Histogram for " + species.split(".gaf")[0].split("_")[-1] + "\n" + msg)
+# 
+#     if options.histogram == "1":
+#         plt.legend(bbox_to_anchor=(0.4, 1))
+#         plt.show()
+#     else:
+#         # plt.figure(figsize=(70,70))
+#         plt.legend(bbox_to_anchor=(0.45, 1))
+#         plt.savefig(filepath, dpi=900)
+#         fhw = open(filepath[:-3] + ".txt", "w")
+#         fhw.write(str(new_prev_val) + "\n" + str(new_lat_val))
+#     plt.close()
 
 
-def write_contents_to_file(dataDict, fileName):
-    F = open(fileName + ".txt", "w")
-    for key in dataDict:
-        F.write(str(key) + "\t" + str(dataDict[key]) + "\n")
-    F.close()
+# def write_contents_to_file(dataDict, fileName):
+#     F = open(fileName + ".txt", "w")
+#     for key in dataDict:
+#         F.write(str(key) + "\t" + str(dataDict[key]) + "\n")
+#     F.close()
 
 
 # This function reads the data entered via command line and returns a dictionary with all relevant options
@@ -1010,8 +1101,38 @@ def parse_command_line_arguments():
     return args
 
 
+def init_globals(gothresh_ini_file="gothresher.ini"):
+    """
+    Define global variables
+    """
+    config = configparser.ConfigParser()
+    config.read(gothresh_ini_file)
+    # print("in init_globals")
+    global FILE_ALTERNATE_ID_TO_ID_MAPPING 
+    global FILE_CAFA_ID_TO_UNIPROT_ID_MAP 
+    global FILE_MFO_ONTOLOGY_GRAPH
+    global FILE_BPO_ONTOLOGY_GRAPH
+    global FILE_CCO_ONTOLOGY_GRAPH
+    global FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH
+    global FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH
+    global FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH
+
+    global ONTO_DIR
+# Some filenames
+    ONTO_DIR = os.path.abspath(config['DIRS']['ONTO_DIR'])
+    FILE_ALTERNATE_ID_TO_ID_MAPPING = os.path.join(ONTO_DIR, "alt_to_id.graph")
+    FILE_CAFA_ID_TO_UNIPROT_ID_MAP = os.path.join(ONTO_DIR, "CAFAIDTOUniprotIDMap.txt")
+    FILE_MFO_ONTOLOGY_GRAPH = os.path.join(ONTO_DIR, "mf.graph")
+    FILE_BPO_ONTOLOGY_GRAPH = os.path.join(ONTO_DIR, "bp.graph")
+    FILE_CCO_ONTOLOGY_GRAPH = os.path.join(ONTO_DIR, "cc.graph")
+    FILE_MFO_ONTOLOGY_ANCESTORS_GRAPH = os.path.join(ONTO_DIR, "mf_ancestors.map")
+    FILE_BPO_ONTOLOGY_ANCESTORS_GRAPH = os.path.join(ONTO_DIR, "bp_ancestors.map")
+    FILE_CCO_ONTOLOGY_ANCESTORS_GRAPH = os.path.join(ONTO_DIR, "cc_ancestors.map")
+
+
 def main():
     global verbose, options, report
+    init_globals()
     command_line_arg = sys.argv
     if len(command_line_arg) == 1:
         print("Please use the --help option to get usage information")
@@ -1078,7 +1199,8 @@ def main():
                 report_row.append(count_proteins(data))
                 report_row.append(prev_len)
                 report_row.append(len(data))
-                reportdict[eachinputfile].append(report_row)
+                # reportdict[eachinputfile].append(report_row)
+                reportdict[species].append(report_row)
             vprint()
         if options.aspect is not None:
             vprint("Number of annotations before choosing proteins based on aspect ", len(data))
@@ -1106,7 +1228,8 @@ def main():
                 report_row.append(count_proteins(data))
                 report_row.append(prev_len)
                 report_row.append(len(data))
-                reportdict[eachinputfile].append(report_row)
+                reportdict[species].append(report_row)
+                # reportdict[eachinputfile].append(report_row)
             vprint()
         if options.date_before is not None or options.date_after is not None:
             vprint("Number of annotations before choosing proteins based on provided range of dates ", len(data))
@@ -1120,7 +1243,8 @@ def main():
                 report_row.append(count_proteins(data))
                 report_row.append(prev_len)
                 report_row.append(len(data))
-                reportdict[eachinputfile].append(report_row)
+                reportdict[species].append(report_row)
+                # reportdict[eachinputfile].append(report_row)
             vprint()
         if options.cutoff_prot is not None or options.cutoff_attn is not None:
             vprint("Number of annotations before choosing proteins based on Publications ", len(data))
@@ -1139,8 +1263,8 @@ def main():
             if options.histogram is not None:
                 later_go_term_freq = freq_go_term(data)
                 # write_contents_to_file(later_go_term_freq, "laterInterimFile")
-                generate_histogram(options, data, eachinputfile, prev_go_term_freq, later_go_term_freq,
-                                  "Removal of high Throughput Papers")
+                # generate_histogram(options, data, eachinputfile, prev_go_term_freq, later_go_term_freq,
+                #                   "Removal of high Throughput Papers")
 
             vprint("Number of annotations after choosing proteins based on Publications ", len(data))
             vprint("Data discarded ", prev_len - len(data))
@@ -1164,7 +1288,8 @@ def main():
                 report_row.append(count_proteins(data))
                 report_row.append(prev_len)
                 report_row.append(len(data))
-                reportdict[eachinputfile].append(report_row)
+                reportdict[species].append(report_row)
+                # reportdict[eachinputfile].append(report_row)
             vprint()
         if options.info_threshold_Wyatt_Clark or options.info_threshold_Wyatt_Clark_percentile is not None:
             vprint("Number of annotations before choosing proteins based on Wyatt Clark Threshold ", len(data))
@@ -1181,7 +1306,8 @@ def main():
                 report_row.append(count_proteins(data))
                 report_row.append(prev_len)
                 report_row.append(len(data))
-                reportdict[eachinputfile].append(report_row)
+                # reportdict[eachinputfile].append(report_row)
+                reportdict[species].append(report_row)
             vprint()
 
         write_to_file(data, options.output[file_num], options.input[file_num])
